@@ -61,7 +61,7 @@ lsm_c_circle_cv.RasterLayer <- function(landscape, directions = 8) {
                      FUN = lsm_c_circle_cv_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -77,7 +77,7 @@ lsm_c_circle_cv.RasterStack <- function(landscape, directions = 8) {
                      FUN = lsm_c_circle_cv_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -93,7 +93,7 @@ lsm_c_circle_cv.RasterBrick <- function(landscape, directions = 8) {
                      FUN = lsm_c_circle_cv_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -111,7 +111,7 @@ lsm_c_circle_cv.stars <- function(landscape, directions = 8) {
                      FUN = lsm_c_circle_cv_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -128,7 +128,7 @@ lsm_c_circle_cv.list <- function(landscape, directions = 8) {
                      FUN = lsm_c_circle_cv_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
