@@ -57,7 +57,7 @@ lsm_c_shape_cv.RasterLayer <- function(landscape, directions = 8) {
                      FUN = lsm_c_shape_cv_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -73,7 +73,7 @@ lsm_c_shape_cv.RasterStack <- function(landscape, directions = 8) {
                      FUN = lsm_c_shape_cv_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -89,7 +89,7 @@ lsm_c_shape_cv.RasterBrick <- function(landscape, directions = 8) {
                      FUN = lsm_c_shape_cv_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -107,7 +107,7 @@ lsm_c_shape_cv.stars <- function(landscape, directions = 8) {
                      FUN = lsm_c_shape_cv_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -123,7 +123,7 @@ lsm_c_shape_cv.list <- function(landscape, directions = 8) {
                      FUN = lsm_c_shape_cv_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
