@@ -58,7 +58,7 @@ lsm_l_frac_sd.RasterLayer <- function(landscape, directions = 8) {
                      FUN = lsm_l_frac_sd_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -74,7 +74,7 @@ lsm_l_frac_sd.RasterStack <- function(landscape, directions = 8) {
                      FUN = lsm_l_frac_sd_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -90,7 +90,7 @@ lsm_l_frac_sd.RasterBrick <- function(landscape, directions = 8) {
                      FUN = lsm_l_frac_sd_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -108,7 +108,7 @@ lsm_l_frac_sd.stars <- function(landscape, directions = 8) {
                      FUN = lsm_l_frac_sd_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -124,7 +124,7 @@ lsm_l_frac_sd.list <- function(landscape, directions = 8) {
                      FUN = lsm_l_frac_sd_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
