@@ -34,12 +34,12 @@ show_patches.RasterLayer <- function(landscape,
                                      nrow = NULL,
                                      ncol = NULL) {
 
-    show_patches_intern(landscape,
-                        class = class,
-                        directions = directions,
-                        labels = labels,
-                        nrow = nrow,
-                        ncol = ncol)
+    show_patches_internal(landscape,
+                          class = class,
+                          directions = directions,
+                          labels = labels,
+                          nrow = nrow,
+                          ncol = ncol)
 }
 
 #' @name show_patches
@@ -52,7 +52,7 @@ show_patches.RasterStack <- function(landscape,
                                      ncol = NULL) {
 
     lapply(X = raster::as.list(landscape),
-           FUN = show_patches_intern,
+           FUN = show_patches_internal,
            class = class,
            directions = directions,
            labels = labels,
@@ -70,7 +70,7 @@ show_patches.RasterBrick <- function(landscape,
                                      ncol = NULL) {
 
     lapply(X = raster::as.list(landscape),
-           FUN = show_patches_intern,
+           FUN = show_patches_internal,
            class = class,
            directions = directions,
            labels = labels,
@@ -89,8 +89,8 @@ show_patches.stars <- function(landscape,
 
     landscape <- methods::as(landscape, "Raster")
 
-    lapply(X = landscape,
-           FUN = show_patches_intern,
+    lapply(X = raster::as.list(landscape),
+           FUN = show_patches_internal,
            class = class,
            directions = directions,
            labels = labels,
@@ -108,7 +108,7 @@ show_patches.list <- function(landscape,
                               ncol = NULL) {
 
     lapply(X = landscape,
-           FUN = show_patches_intern,
+           FUN = show_patches_internal,
            class = class,
            directions = directions,
            labels = labels,
@@ -116,7 +116,7 @@ show_patches.list <- function(landscape,
            ncol = ncol)
 }
 
-show_patches_intern <- function(landscape, class, directions, labels, nrow, ncol) {
+show_patches_internal <- function(landscape, class, directions, labels, nrow, ncol) {
 
     if(any(!(class %in% c("all", "global")))){
         if (!any(class %in% raster::unique(landscape))){
@@ -147,11 +147,11 @@ show_patches_intern <- function(landscape, class, directions, labels, nrow, ncol
 
         patches_tibble$value <- replace(patches_tibble$value, patches_tibble$value == 0, NA)
 
-        if (isTRUE(labels)) {
+        if (labels) {
             patches_tibble$labels <- patches_tibble$value
         }
 
-        if (!isTRUE(labels)) {
+        if (!labels) {
             patches_tibble$labels <- NA
         }
 
@@ -174,11 +174,11 @@ show_patches_intern <- function(landscape, class, directions, labels, nrow, ncol
             patches_tibble <- patches_tibble[class_index, ]
         }
 
-        if (isTRUE(labels)) {
+        if (labels) {
             patches_tibble$labels <- patches_tibble$value
         }
 
-        if (!isTRUE(labels)) {
+        if (!labels) {
             patches_tibble$labels <- NA
         }
     }
