@@ -1,11 +1,14 @@
 context("pad_raster")
 
 test_that("pad_raster can handle all raster inputs", {
-    expect_is(landscapemetrics:::pad_raster(landscape), "list")
-    expect_is(landscapemetrics:::pad_raster(landscape_stack), "list")
-    expect_is(landscapemetrics:::pad_raster(landscape_brick), "list")
-    expect_is(landscapemetrics:::pad_raster(landscape_list), "list")
-    expect_is(landscapemetrics:::pad_raster(raster::as.matrix(landscape)), "list")
+
+    landscape_matrix <- raster::as.matrix(landscape)
+
+    expect_is(pad_raster(landscape), "list")
+    expect_is(pad_raster(landscape_stack), "list")
+    expect_is(pad_raster(landscape_brick), "list")
+    expect_is(pad_raster(landscape_list), "list")
+    expect_is(pad_raster(landscape_matrix, return_raster = FALSE), "list")
 })
 
 test_that("pad_raster can add more than one row", {
